Rev 3820: Continue tracking down all the references to development3/4 in http://bzr.arbash-meinel.com/branches/bzr/brisbane/inv_as_lines

John Arbash Meinel john at arbash-meinel.com
Fri Feb 13 20:04:53 GMT 2009


At http://bzr.arbash-meinel.com/branches/bzr/brisbane/inv_as_lines

------------------------------------------------------------
revno: 3820
revision-id: john at arbash-meinel.com-20090213200419-ygy7lh2r2wpeo8k6
parent: john at arbash-meinel.com-20090213195448-od86qjddx7zo784i
committer: John Arbash Meinel <john at arbash-meinel.com>
branch nick: inv_as_lines
timestamp: Fri 2009-02-13 14:04:19 -0600
message:
  Continue tracking down all the references to development3/4
  
  Start working on getting the test suite to pass again.
  Using command: 
    bzr selftest -s bt.test_chk -s bt.test_inv -s bt.per_repository_chk -s bt.test_pack_repo
  Still have about 30 failures.
-------------- next part --------------
=== modified file 'bzrlib/repofmt/pack_repo.py'
--- a/bzrlib/repofmt/pack_repo.py	2009-02-12 23:03:07 +0000
+++ b/bzrlib/repofmt/pack_repo.py	2009-02-13 20:04:19 +0000
@@ -2952,7 +2952,7 @@
     def get_format_string(self):
         """See RepositoryFormat.get_format_string()."""
         return ("Bazaar development format 5 with subtree support"
-                " (needs bzr.dev from before 1.11)\n")
+                " (needs bzr.dev from before 1.13)\n")
 
     def get_format_description(self):
         """See RepositoryFormat.get_format_description()."""

=== modified file 'bzrlib/tests/intertree_implementations/__init__.py'
--- a/bzrlib/tests/intertree_implementations/__init__.py	2008-11-14 08:38:12 +0000
+++ b/bzrlib/tests/intertree_implementations/__init__.py	2009-02-13 20:04:19 +0000
@@ -176,7 +176,7 @@
     # CHKInventory does not have an InterTree optimiser class (yet).
     chk_tree_format = WorkingTreeFormat4()
     chk_tree_format._get_matchingbzrdir = \
-        lambda:bzrlib.bzrdir.format_registry.make_bzrdir('development3')
+        lambda:bzrlib.bzrdir.format_registry.make_bzrdir('development5')
     test_intertree_permutations.append(
         (InterTree.__name__ + "(CHKInventory)",
          InterTree,

=== modified file 'bzrlib/tests/per_repository_chk/__init__.py'
--- a/bzrlib/tests/per_repository_chk/__init__.py	2008-09-30 01:52:14 +0000
+++ b/bzrlib/tests/per_repository_chk/__init__.py	2009-02-13 20:04:19 +0000
@@ -30,7 +30,7 @@
 from bzrlib.bzrdir import BzrDir
 from bzrlib.repofmt.pack_repo import (
     RepositoryFormatKnitPack5,
-    RepositoryFormatPackDevelopment3,
+    RepositoryFormatPackDevelopment5,
     )
 from bzrlib.tests import (
                           adapt_modules,
@@ -64,7 +64,7 @@
         if isinstance(format, remote.RemoteRepositoryFormat):
             with_support = dict(scenario_info)
             with_support['repository_format'] = \
-                RepositoryFormatPackDevelopment3()
+                RepositoryFormatPackDevelopment5()
             supported.append((test_name + "(Supported)", with_support))
             no_support = dict(scenario_info)
             no_support['repository_format'] = RepositoryFormatKnitPack5()

=== modified file 'bzrlib/tests/test_chk_map.py'
--- a/bzrlib/tests/test_pack_repository.py	2008-12-07 16:46:56 +0000
+++ b/bzrlib/tests/test_pack_repository.py	2009-02-13 20:04:19 +0000
@@ -208,10 +208,14 @@
         check_result = tree.branch.repository.check(
             [tree.branch.last_revision()])
         # We should have 50 (10x5) files in the obsolete_packs directory.
+        # If supports_chks, then we have 60
         obsolete_files = list(trans.list_dir('obsolete_packs'))
         self.assertFalse('foo' in obsolete_files)
         self.assertFalse('bar' in obsolete_files)
-        self.assertEqual(50, len(obsolete_files))
+        if tree.branch.repository.supports_chks:
+            self.assertEqual(60, len(obsolete_files))
+        else:
+            self.assertEqual(50, len(obsolete_files))
         # XXX: Todo check packs obsoleted correctly - old packs and indices
         # in the obsolete_packs directory.
         large_pack_name = list(index.iter_all_entries())[0][1][0]
@@ -600,7 +604,7 @@
             # metadata
             if getattr(repo._format, 'supports_tree_reference', False):
                 if repo._format.supports_chks:
-                    matching_format_name = 'development3-subtree'
+                    matching_format_name = 'development5-subtree'
                 else:
                     matching_format_name = 'pack-0.92-subtree'
             else:
@@ -608,7 +612,7 @@
             mismatching_format_name = 'pack-0.92'
         else:
             if repo._format.supports_chks:
-                matching_format_name = 'development3'
+                matching_format_name = 'development5'
             else:
                 matching_format_name = 'pack-0.92'
             mismatching_format_name = 'pack-0.92-subtree'
@@ -630,7 +634,7 @@
             # can only stack on repositories that have compatible internal
             # metadata
             if repo._format.supports_chks:
-                matching_format_name = 'development3-subtree'
+                matching_format_name = 'development5-subtree'
             else:
                 matching_format_name = 'pack-0.92-subtree'
             mismatching_format_name = 'rich-root-pack'
@@ -784,24 +788,24 @@
                   "with subtree support (needs bzr.dev from before 1.8)\n",
               format_supports_external_lookups=True,
               index_class=BTreeGraphIndex),
-         dict(format_name='development3',
-              format_string="Bazaar development format 3 "
-                  "(needs bzr.dev from before 1.10)\n",
-              format_supports_external_lookups=True,
-              index_class=BTreeGraphIndex),
-         dict(format_name='development3-subtree',
-              format_string="Bazaar development format 3 "
-                  "with subtree support (needs bzr.dev from before 1.10)\n",
-              format_supports_external_lookups=True,
-              index_class=BTreeGraphIndex),
-         dict(format_name='development4',
-              format_string="Bazaar development format 4 "
-                  "(needs bzr.dev from before 1.10)\n",
-              format_supports_external_lookups=True,
-              index_class=BTreeGraphIndex),
-         dict(format_name='development4-subtree',
-              format_string="Bazaar development format 4 "
-                  "with subtree support (needs bzr.dev from before 1.10)\n",
+         dict(format_name='development5',
+              format_string="Bazaar development format 5 "
+                  "(needs bzr.dev from before 1.13)\n",
+              format_supports_external_lookups=True,
+              index_class=BTreeGraphIndex),
+         dict(format_name='development5-subtree',
+              format_string="Bazaar development format 5 "
+                  "with subtree support (needs bzr.dev from before 1.13)\n",
+              format_supports_external_lookups=True,
+              index_class=BTreeGraphIndex),
+         dict(format_name='development5-hash16',
+              format_string="Bazaar development format 5 hash 16"
+                            " (needs bzr.dev from before 1.13)\n",
+              format_supports_external_lookups=True,
+              index_class=BTreeGraphIndex),
+         dict(format_name='development5-hash255',
+              format_string="Bazaar development format 5 hash 255"
+                            " (needs bzr.dev from before 1.13)\n",
               format_supports_external_lookups=True,
               index_class=BTreeGraphIndex),
          ]

=== modified file 'bzrlib/tests/test_repository.py'
--- a/bzrlib/tests/test_repository.py	2009-01-12 18:44:55 +0000
+++ b/bzrlib/tests/test_repository.py	2009-02-13 20:04:19 +0000
@@ -668,7 +668,7 @@
 class TestDevelopment3(TestCaseWithTransport):
 
     def test_add_inventory_uses_chk_map(self):
-        repo = self.make_repository('repo', format="development3")
+        repo = self.make_repository('repo', format="development5")
         source = self.make_branch_and_tree("source", format="pack-0.92")
         revid = source.commit("foo", rev_id="foo")
         # get the inventory from the committed revision
@@ -690,10 +690,10 @@
         self.assertEqual(4096, inv.id_to_entry._root_node.maximum_size)
 
 
-class TestDevelopment4(TestCaseWithTransport):
+class TestDevelopment5(TestCaseWithTransport):
 
     def test_inventories_use_chk_map_with_parent_base_dict(self):
-        tree = self.make_branch_and_tree('repo', format="development4")
+        tree = self.make_branch_and_tree('repo', format="development5")
         revid = tree.commit("foo")
         tree.lock_read()
         self.addCleanup(tree.unlock)
@@ -706,12 +706,12 @@
             inv.parent_id_basename_to_file_id._root_node.maximum_size)
 
 
-class TestDevelopment3FindRevisionOutsideSet(TestCaseWithTransport):
+class TestDevelopment5FindRevisionOutsideSet(TestCaseWithTransport):
     """Tests for _find_revision_outside_set."""
 
     def setUp(self):
         super(TestDevelopment3FindRevisionOutsideSet, self).setUp()
-        self.builder = self.make_branch_builder('source', format='development3')
+        self.builder = self.make_branch_builder('source', format='development5')
         self.builder.start_series()
         self.builder.build_snapshot('initial', None,
             [('add', ('', 'tree-root', 'directory', None))])



More information about the bazaar-commits mailing list
--- a/bzrlib/tests/test_chk_map.py	2009-02-12 20:55:35 +0000
+++ b/bzrlib/tests/test_chk_map.py	2009-02-13 20:04:19 +0000
@@ -34,9 +34,9 @@
 class TestCaseWithStore(TestCaseWithTransport):
 
     def get_chk_bytes(self):
         # The eassiest way to get a CHK store is a development3 repository and
         # then work with the chk_bytes attribute directly.
-        repo = self.make_repository(".", format="development3")
+        repo = self.make_repository(".", format="development5")
         repo.lock_write()
         self.addCleanup(repo.unlock)
         repo.start_write_group()
@@ -34,9 +34,9 @@
 
     def get_chk_bytes(self):
-        # The eassiest way to get a CHK store is a development3 repository and
+        # The eassiest way to get a CHK store is a development5 repository and
         # then work with the chk_bytes attribute directly.

=== modified file 'bzrlib/tests/test_inv.py'
--- a/bzrlib/tests/test_inv.py	2009-01-21 23:04:50 +0000
+++ b/bzrlib/tests/test_inv.py	2009-02-13 20:04:19 +0000
@@ -171,9 +171,9 @@
 class TestCHKInventory(TestCaseWithTransport):
     
     def get_chk_bytes(self):
         # The eassiest way to get a CHK store is a development3 repository and
         # then work with the chk_bytes attribute directly.
-        repo = self.make_repository(".", format="development3")
+        repo = self.make_repository(".", format="development5")
         repo.lock_write()
         self.addCleanup(repo.unlock)
         repo.start_write_group()
@@ -171,9 +171,9 @@
     
     def get_chk_bytes(self):
-        # The eassiest way to get a CHK store is a development3 repository and
+        # The eassiest way to get a CHK store is a development5 repository and
         # then work with the chk_bytes attribute directly.

=== modified file 'bzrlib/tests/test_pack_repository.py'